bayespy.nodes.VaryingGaussianMarkovChain.lower_bound_contribution
=================================================================

.. currentmodule:: bayespy.nodes

.. automethod:: VaryingGaussianMarkovChain.lower_bound_contribution